@@ -1,4 +1,5 @@
 #!/usr/bin/perl -w
+use lib qw(lib);
 use HTML::Menu::TreeView;
 use CGI;
 use strict;
@@ -6,18 +7,18 @@ my $q = new CGI;
 my @tree = (
             {
              text     => 'what',
+             style    => 'width:100px;',
              addition => $q->checkbox(
                                       -name  => 'what',
                                       -value => 'what',
-                                      -label => ''
              ),
             },
             {
              text     => 'Whatever',
+             style    => 'width:100px;',
              addition => $q->checkbox(
                                       -name  => 'Whatever',
                                       -value => 'Whatever',
-                                      -label => ''
              ),
             }
 );
