@@ -4,21 +4,23 @@ use warnings;
 require Exporter;
 use 5.00600;
 use utf8;
+no warnings  'deprecated'; 
+
 use vars qw($DefaultClass %EXPORT_TAGS @EXPORT_OK @ISA %anker @TreeView %openArrays @caption $columns $clasic $ffirst $sort $border $orderby $size $style $orderbyColumn $prefix $bTrOver $desc %anker %ankerG $lang);
-$HTML::Menu::TreeView::VERSION = '1.15';
+$HTML::Menu::TreeView::VERSION = '1.16';
 @ISA                           = qw(Exporter);
 @HTML::Menu::TreeView::EXPORT_OK =
   qw(border Tree css columns jscript setStyle setDocumentRoot getDocumentRoot setSize setClasic clasic preload help folderFirst size style Style documentRoot loadTree saveTree  %anker %ankerG sortTree orderBy orderByColumn prefix setModern border TrOver desc language);
 %HTML::Menu::TreeView::EXPORT_TAGS = (
-                                      'all'       => [qw(Tree css jscript clasic columns preload help folderFirst size documentRoot loadTree saveTree sortTree orderBy prefix Style orderByColumn border TrOver desc language)],
-                                      'recommend' => [qw(Tree css jscript clasic preload folderFirst help size Style documentRoot loadTree saveTree sortTree prefix desc)],
-                                      'standart'  => [qw(Tree css jscript preload size Style documentRoot clasic)],
-                                      'backward'  => [qw(setDocumentRoot getDocumentRoot setSize setClasic setStyle style setModern)],
-                                      'columns'   => [qw(border columns orderByColumn orderBy)],
+  'all'       => [qw(Tree css jscript clasic columns preload help folderFirst size documentRoot loadTree saveTree sortTree orderBy prefix Style orderByColumn border TrOver desc language)],
+  'recommend' => [qw(Tree css jscript clasic preload folderFirst help size Style documentRoot loadTree saveTree sortTree prefix desc)],
+  'standart'  => [qw(Tree css jscript preload size Style documentRoot clasic)],
+  'backward'  => [qw(setDocumentRoot getDocumentRoot setSize setClasic setStyle style setModern)],
+  'columns'   => [qw(border columns orderByColumn orderBy)],
 );
 $DefaultClass = 'HTML::Menu::TreeView' unless defined $HTML::Menu::TreeView::DefaultClass;
 our $id       = 'a';
-our $path     = '/var/www/htdocs';
+our $path     = '%PATH%';
 our $saveFile = './TreeViewDump.pl';
 $lang  = 'en';
 $style = 'Crystal';
@@ -27,68 +29,68 @@ $size  = 16;
 $orderby = 'text';
 $prefix  = '';
 %anker = (
-          name        => 'The name of the Element',
-          href        => 'URI for linked resource',
-          accesskey   => 'accessibility key character',
-          charset     => 'char encoding of linked resource',
-          class       => 'class name or set of class names to an element.',
-          coords      => 'for use with client-side image maps',
-          dir         => 'the base direction of directionally neutral text',
-          hreflang    => 'language code',
-          lang        => 'the base language of an elements attribute values and text content.',
-          onblur      => 'the element lost the focus',
-          ondblclick  => 'event occurs when the pointing device button is double clicked ',
-          onclick     => 'event occurs when the pointing device button is clicked over an element',
-          onfocus     => 'the element got the focus',
-          onkeydown   => 'event occurs when a key is pressed down over an element.',
-          onkeypress  => 'event occurs when a key is pressed and released over an element.',
-          onkeyup     => 'event occurs when a key is released over an element.',
-          onmousedown => 'event occurs when the pointing device button is pressed over an element.',
-          onmousemove => 'event occurs when the pointing device is moved while it is over an element.',
-          onmouseout  => 'event occurs when the pointing device is moved away from an element.',
-          onmouseover => 'event occurs when the pointing device is moved onto an element.',
-          onmouseup   => 'event occurs when the pointing device button is released over an element.',
-          rel         => 'forward link types',
-          rev         => 'reverse link types',
-          shape       => 'for use with client-side image maps',
-          style       => 'specifies style information for the current element.',
-          tabindex    => 'position in tabbing order',
-          target      => 'target frame information',
-          type        => 'advisory content type ',
-          title       => 'element title',
-          id          => 'This attribute assigns a name to an element. This name must be unique in a document.',
+  name        => 'The name of the Element',
+  href        => 'URI for linked resource',
+  accesskey   => 'accessibility key character',
+  charset     => 'char encoding of linked resource',
+  class       => 'class name or set of class names to an element.',
+  coords      => 'for use with client-side image maps',
+  dir         => 'the base direction of directionally neutral text',
+  hreflang    => 'language code',
+  lang        => 'the base language of an elements attribute values and text content.',
+  onblur      => 'the element lost the focus',
+  ondblclick  => 'event occurs when the pointing device button is double clicked ',
+  onclick     => 'event occurs when the pointing device button is clicked over an element',
+  onfocus     => 'the element got the focus',
+  onkeydown   => 'event occurs when a key is pressed down over an element.',
+  onkeypress  => 'event occurs when a key is pressed and released over an element.',
+  onkeyup     => 'event occurs when a key is released over an element.',
+  onmousedown => 'event occurs when the pointing device button is pressed over an element.',
+  onmousemove => 'event occurs when the pointing device is moved while it is over an element.',
+  onmouseout  => 'event occurs when the pointing device is moved away from an element.',
+  onmouseover => 'event occurs when the pointing device is moved onto an element.',
+  onmouseup   => 'event occurs when the pointing device button is released over an element.',
+  rel         => 'forward link types',
+  rev         => 'reverse link types',
+  shape       => 'for use with client-side image maps',
+  style       => 'specifies style information for the current element.',
+  tabindex    => 'position in tabbing order',
+  target      => 'target frame information',
+  type        => 'advisory content type ',
+  title       => 'element title',
+  id          => 'This attribute assigns a name to an element. This name must be unique in a document.',
 );
 %ankerG = (
-           name        => 'Name des Links',
-           href        => 'Adresse die aufgerufen wird',
-           accesskey   => 'Zugriffstaste',
-           charset     => 'Zeichenkodierung der Zieladresse',
-           class       => 'Klassen Name',
-           coords      => 'F&#252;r Imagemaps',
-           dir         => 'Leserichtung',
-           hreflang    => 'Sprache des Ziels',
-           lang        => 'Sprache des Inhaltes',
-           onblur      => 'Anker verliert den Fokus',
-           ondblclick  => 'Maus wird doppelgeklickt',
-           onclick     => 'Maus wird geklickt',
-           onfocus     => 'Link erh&#228;lt den Fokus',
-           onkeydown   => 'Eine Taste wird gedr&#252;ckt.',
-           onkeypress  => 'Eine Taste wird gedr&#252;ckt',
-           onkeyup     => 'Eine Taste wird los gelassen',
-           onmousedown => 'Maus wird gedr&#252;ckt',
-           onmousemove => 'Maus wird bewegt',
-           onmouseout  => 'Maus verl&#228;sst den Anker',
-           onmouseover => 'Maus betritt den Anker',
-           onmouseup   => 'Maus wird losgelassen',
-           rel         => 'Logische Vorw&#228;rtsbeziehung <a href="http://de.selfhtml.org/html/verweise/typisierte.htm#sprache_zeichenkodierug">siehe selfhtml</a>',
-           rev         => 'Logische R&#252;ckw&#228;rtsbeziehung',
-           shape       => 'Imagemaps',
-           style       => 'Formatierungs Informationen',
-           tabindex    => 'Tabstopp position',
-           target      => 'Ziel Frame Angabe',
-           type        => 'Content-type',
-           title       => 'Titel',
-           id          => 'Identifikator. Muss einmalig im Dokument sein',
+  name        => 'Name des Links',
+  href        => 'Adresse die aufgerufen wird',
+  accesskey   => 'Zugriffstaste',
+  charset     => 'Zeichenkodierung der Zieladresse',
+  class       => 'Klassen Name',
+  coords      => 'F&#252;r Imagemaps',
+  dir         => 'Leserichtung',
+  hreflang    => 'Sprache des Ziels',
+  lang        => 'Sprache des Inhaltes',
+  onblur      => 'Anker verliert den Fokus',
+  ondblclick  => 'Maus wird doppelgeklickt',
+  onclick     => 'Maus wird geklickt',
+  onfocus     => 'Link erh&#228;lt den Fokus',
+  onkeydown   => 'Eine Taste wird gedr&#252;ckt.',
+  onkeypress  => 'Eine Taste wird gedr&#252;ckt',
+  onkeyup     => 'Eine Taste wird los gelassen',
+  onmousedown => 'Maus wird gedr&#252;ckt',
+  onmousemove => 'Maus wird bewegt',
+  onmouseout  => 'Maus verl&#228;sst den Anker',
+  onmouseover => 'Maus betritt den Anker',
+  onmouseup   => 'Maus wird losgelassen',
+  rel         => 'Logische Vorw&#228;rtsbeziehung <a href="http://de.selfhtml.org/html/verweise/typisierte.htm#sprache_zeichenkodierug">siehe selfhtml</a>',
+  rev         => 'Logische R&#252;ckw&#228;rtsbeziehung',
+  shape       => 'Imagemaps',
+  style       => 'Formatierungs Informationen',
+  tabindex    => 'Tabstopp position',
+  target      => 'Ziel Frame Angabe',
+  type        => 'Content-type',
+  title       => 'Titel',
+  id          => 'Identifikator. Muss einmalig im Dokument sein',
 );
 
 =head1 NAME
@@ -284,7 +286,7 @@ sub css
     my $css;
 
     foreach my $l (@lines) {
-        $l =~ s?/style/?$prefix/style/?g;
+#         $l =~ s?/style/?style/?g;
         $css .= $l;
     }
     return $css;
@@ -371,7 +373,7 @@ sub preload
     my $preload;
 
     foreach my $l (@lines) {
-        $l =~ s?/style/?$prefix/style/?g;
+        $l =~ s?/style/?style/?g;
         $preload .= $l;
     }
     return $preload;
@@ -1135,6 +1137,7 @@ sub initTree
     for (my $i = 0; $i < @$tree; $i++) {
         next if ref @$tree[$i] ne "HASH";
         $length--;
+        no warnings  'deprecated';
         if (defined @$tree[$i]) {
              if (defined @{@$tree[$i]->{subtree}} && not defined @$tree[$i]->{empty}) {#a smalll fix, sorting closed folders will work with this change.
                 if ($length > 0) {
@@ -1247,7 +1250,7 @@ sub appendFolder
       : "&#160;<a $tt >$node->{text}</a>&#160;";
     my $minusnode = $clasic ? "clasicMinusNode$size" : "minusNode$size";
     $self->{tree} .= ( $bTrOver ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">) : '<tr>' )
-      . qq(<td id="$id.node" class="$minusnode"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td align="left" class="$FolderClass" id="$id.folder" ><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td $st align="left">$addon</td></tr></table></td></tr><tr id="$id"><td class="submenuDeco$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt=""/></td><td class="subtree"><table align="left" border="0" cellpadding="0" cellspacing="0"   summary="appendFolder" width="100%"><colgroup><col width="$size"/></colgroup>);
+      . qq(<td id="$id.node" class="$minusnode"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td align="left" class="$FolderClass" id="$id.folder" ><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td $st align="left">$addon</td></tr></table></td></tr><tr id="$id"><td class="submenuDeco$size"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt=""/></td><td class="subtree"><table align="left" border="0" cellpadding="0" cellspacing="0"   summary="appendFolder" width="100%"><colgroup><col width="$size"/></colgroup>);
 
     if ($columns > 0) {
         my $class = $border ? "columnsFolderBorder$size" : "columnsFolder$size";
@@ -1325,7 +1328,7 @@ sub appendLastFolder
                       ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">)
                       : '<tr>'
       )
-      . qq(<td id="$id.node" class="$lastminusnode" onclick="$onclick"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" /></td><td align="left" class="$FolderClass" id="$id.folder"><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendLastFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt="" onclick="$onclick"/></td><td $st align="left">$addon</td></tr></table></td></tr><tr id="$id"><td class="subtree"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt=""/></td><td class="subtree"><table align="left" width="100%" cellpadding="0" cellspacing="0" border="0" summary="appendLastFolder"><colgroup><col width="$size"/></colgroup>);
+      . qq(<td id="$id.node" class="$lastminusnode" onclick="$onclick"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" /></td><td valign="top" align="left" class="$FolderClass" id="$id.folder"><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendLastFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt="" onclick="$onclick"/></td><td $st align="left" valign="top" >$addon</td></tr></table></td></tr><tr id="$id"><td class="subtree"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt=""/></td><td class="subtree"><table align="left" width="100%" cellpadding="0" cellspacing="0" border="0" summary="appendLastFolder"><colgroup><col width="$size"/></colgroup>);
 
     if ($columns > 0) {
         my $class = $border ? "columnsFolderBorder$size" : "columnsFolder$size";
@@ -1393,7 +1396,7 @@ sub appendEmptyFolder
                       ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">)
                       : '<tr>'
       )
-      . qq(<td id="$id.node" class="$plusnode"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td align="left" class="$FolderClass" id="$id.folder"><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td $st align="left">$addon</td></tr></table></td></tr>);
+      . qq(<td id="$id.node" class="$plusnode"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td align="left" class="$FolderClass" id="$id.folder" valign="top" ><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td $st align="left" valign="top" >$addon</td></tr></table></td></tr>);
 
     if ($columns > 0) {
         my $class = $border ? "columnsFolderBorder$size" : "columnsFolder$size";
@@ -1460,7 +1463,7 @@ sub appendLastEmptyFolder
                       ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">)
                       : '<tr>'
       )
-      . qq(<td id="$id.node" class="$lastpusnode" onclick="$onclick"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" /></td><td align="left" class="$FolderClass" id="$id.folder"><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendLastFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt="" onclick="$onclick"/></td><td $st align="left">$addon</td></tr></table></td></tr>);
+      . qq(<td id="$id.node" class="$lastpusnode" onclick="$onclick"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" /></td><td align="left"  valign="top" class="$FolderClass" id="$id.folder"><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendLastFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt="" onclick="$onclick"/></td><td $st align="left" valign="top" >$addon</td></tr></table></td></tr>);
 
     if ($columns > 0) {
         my $class = $border ? "columnsFolderBorder$size" : "columnsFolder$size";
@@ -1485,7 +1488,7 @@ sub appendLastEmptyFolder
 
 =head2 appendNode
 
-$self->appendLastNode(\$node);
+$self->appendNode(\$node);
 
 called by initTree() if the current item of the (sub)Tree is a node.
 
@@ -1511,7 +1514,7 @@ sub appendNode
     my $st = $node->{style} = (($columns > 0 or defined $node->{addition}) and not defined $node->{style}) ? 'style="white-space:nowrap;"' : '';
     my $addon =
       defined $node->{addition}
-      ? qq(<table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendNode" width="100%"><tr><td $st>&#160;<a $tt >$node->{text}</a>&#160;</td><td $st>$node->{addition}</td></tr></table>)
+      ? qq(<table align="left" border="0" cellpadding="0" cellspacing="0" width="100%"><tr><td $st>&#160;<a $tt>$node->{text}</a>&#160;</td><td $st>$node->{addition}</td></tr></table>)
       : "&#160;<a $tt>$node->{text}</a>";
     my $paddingLeft = $size + 2 . "px";
     $self->{tree} .= (
@@ -1519,7 +1522,7 @@ sub appendNode
                       ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">)
                       : '<tr>'
       )
-      . qq(<td class="node$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" align="middle"/></td><td align="left"  style="background-image:url('$prefix/style/$style/$size/mimetypes/$node->{image}');background-repeat:no-repeat;cursor:pointer;background-position:0px 5px;;padding-left:$paddingLeft">$addon</td></tr>);
+      . qq(<td class="node$size"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" align="middle"/></td><td align="left"  style="background-image:url('/style/$style/$size/mimetypes/$node->{image}');background-repeat:no-repeat;cursor:pointer;background-position:0px 5px;;padding-left:$paddingLeft">$addon</td></tr>);
     if ($columns > 0) {
         $self->{subtree} .= (
                              $bTrOver
@@ -1565,7 +1568,7 @@ sub appendLastNode
     my $st = $node->{style} = (($columns > 0 or defined $node->{addition}) and not defined $node->{style}) ? 'style="white-space:nowrap;"' : '';
     my $addon =
       defined $node->{addition}
-      ? qq(<table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendLastNode" width="100%"><tr><td $st><a $tt>$node->{text}</a></td><td $st>$node->{addition}</td></tr></table>)
+      ? qq(<table align="left" border="0" cellpadding="0" cellspacing="0" width="100%"><tr><td $st>&#160;<a $tt>$node->{text}</a>&#160;</td><td $st>$node->{addition}</td></tr></table>)
       : "&#160;<a $tt>$node->{text}</a>";
     my $paddingLeft = $size + 2 . "px";
     $self->{tree} .= (
@@ -1573,7 +1576,7 @@ sub appendLastNode
                       ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">)
                       : '<tr>'
       )
-      . qq(<td class="lastNode$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt=""/></td><td align="left"  style="background-image:url('$prefix/style/$style/$size/mimetypes/$node->{image}');background-repeat:no-repeat;cursor:pointer;background-position:0px 5px;;padding-left:$paddingLeft;">$addon</td></tr>);
+      . qq(<td class="lastNode$size"><img src="/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt=""/></td><td align="left"  style="background-image:url('/style/$style/$size/mimetypes/$node->{image}');background-repeat:no-repeat;cursor:pointer;background-position:0px 5px;;padding-left:$paddingLeft;">$addon</td></tr>);
     if ($columns > 0) {
         my $class = $border ? "columnsLastNodeBorder$size" : "columnsLastNode$size";
         $self->{subtree} .= (
@@ -1597,7 +1600,7 @@ http://lindnerei.sourceforge.net
 
 =head1 AUTHOR
 
-Dirk Lindner <dirk.lze@gmail.com>
+Dirk Lindner <lze@cpan.org>
 
 =head1 LICENSE
 
